import type { Router } from 'vue-router';
import NProgress from 'nprogress'; // progress bar

import { useUserStore } from '@/store';

export default function setupUserLoginInfoGuard(router: Router) {
  router.beforeEach(async (to, from, next) => {
    NProgress.start();
    const userStore = useUserStore();
    if (!to.meta.requiresAuth) {
      next();
      return;
    }
    if (userStore.accessToken) {
      next();
    } else {
      if (to.name === 'Login') {
        next();
        return;
      }
      const paramDomainCode = window.sessionStorage.getItem('paramDomainCode');
      if (paramDomainCode) {
        next({ name: 'Login', query: { code: paramDomainCode } });
        return;
      }

      const routeDomainCode = window.sessionStorage.getItem('routeDomainCode');
      if (routeDomainCode) {
        next({ name: 'Login', params: { code: routeDomainCode } });
        return;
      }

      next({
        name: 'Login',
      });
    }
  });
}
