import { defineStore } from 'pinia';
import ls from '@/utils/storage';
import { removeRouteListener } from '@/utils/route-listener';
import { userLogout } from '@/api/user';
import { UserState } from './types';

const useUserStore = defineStore('user', {
  state: (): UserState => ({
    id: undefined,
    loginName: undefined,
    realName: undefined,
    sessionId: undefined,
    accessToken: undefined,
    schoolInfo: [],
    curSchoolInfo: {},
    orgInfo: {},
    roleList: [],
    role: [],
    time: undefined,
    appSource: undefined,
    pwdCount: undefined,
    userLoginCheckResult: {
      userId: undefined,
      mobileNumber: undefined,
      pwdCount: undefined,
    },
    roleSource: [],
    returnUrl: undefined,
    version: undefined,
  }),

  getters: {
    userInfo(state: UserState): UserState {
      return { ...state };
    },
  },

  actions: {
    setInfo(partial: Partial<UserState>) {
      this.$patch(partial);
    },
    resetInfo() {
      this.$reset();
    },
    // Logout
    async logout() {
      // TODO:如果token已经失效，不用调退出接口
      await userLogout().catch(() => {});
      this.resetInfo();
      removeRouteListener();

      const returnUrl = ls.get('returnUrl');
      if (returnUrl) {
        window.location.href = returnUrl;
        return;
      }

      ls.clear();
      window.location.reload();
    },
  },
  persist: {
    storage: sessionStorage,
  },
});

export default useUserStore;
